@@ -10,6 +10,8 @@ import typing_extensions
 
 import aws_cdk.aws_cloudfront._jsii
 import aws_cdk.aws_cloudfront_origins._jsii
+import aws_cdk.aws_iam._jsii
+import aws_cdk.aws_kinesisfirehose._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_lambda_nodejs._jsii
 import aws_cdk.aws_s3._jsii
@@ -20,9 +22,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-cloudfront-plus",
-    "0.1.33",
+    "0.2.6",
     __name__[0:-6],
-    "cdk-cloudfront-plus@0.1.33.jsii.tgz",
+    "cdk-cloudfront-plus@0.2.6.jsii.tgz",
 )
 
 __all__ = [
